==> com.liferay.knowledge.base.web-1.0.28-sources.jar: com/liferay/knowledge/base/web/internal/constants/KBWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.knowledge.base.web.internal.constants;

/**
 * @author Brian Wing Shun Chan
 * @author Peter Shin
 */
public class KBWebKeys implements com.liferay.portal.kernel.util.WebKeys {

	public static final String DL_MIME_TYPE_DISPLAY_CONTEXT =
		"DL_MIME_TYPE_DISPLAY_CONTEXT";

	public static final String KNOWLEDGE_BASE_EXACT_MATCH =
		"KNOWLEDGE_BASE_EXACT_MATCH";

	public static final String KNOWLEDGE_BASE_KB_ARTICLE =
		"KNOWLEDGE_BASE_KB_ARTICLE";

	public static final String KNOWLEDGE_BASE_KB_ARTICLES =
		"KNOWLEDGE_BASE_KB_ARTICLES";

	public static final String KNOWLEDGE_BASE_KB_FOLDERS =
		"KNOWLEDGE_BASE_KB_FOLDERS";

	public static final String KNOWLEDGE_BASE_KB_NAVIGATION_DISPLAY_CONTEXT =
		"KNOWLEDGE_BASE_KB_NAVIGATION_DISPLAY_CONTEXT";

	public static final String
		KNOWLEDGE_BASE_KB_SUGGESTION_LIST_DISPLAY_CONTEXT =
			"KNOWLEDGE_BASE_KB_SUGGESTION_LIST_DISPLAY_CONTEXT";

	public static final String KNOWLEDGE_BASE_KB_TEMPLATE =
		"KNOWLEDGE_BASE_KB_TEMPLATE";

	public static final String KNOWLEDGE_BASE_PARENT_KB_ARTICLE =
		"KNOWLEDGE_BASE_PARENT_KB_ARTICLE";

	public static final String KNOWLEDGE_BASE_PARENT_KB_FOLDER =
		"KNOWLEDGE_BASE_PARENT_KB_FOLDER";

	public static final String KNOWLEDGE_BASE_SEARCH_KEYWORDS =
		"KNOWLEDGE_BASE_SEARCH_KEYWORDS";

	public static final String KNOWLEDGE_BASE_STATUS = "KNOWLEDGE_BASE_STATUS";

	public static final String SHOW_SIDEBAR_HEADER = "SHOW_SIDEBAR_HEADER";

}

==> com.liferay.knowledge.base.web-2.0.8-sources.jar: com/liferay/knowledge/base/web/internal/constants/KBWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.knowledge.base.web.internal.constants;

import com.liferay.portal.kernel.util.WebKeys;

/**
 * @author Brian Wing Shun Chan
 * @author Peter Shin
 */
public class KBWebKeys implements WebKeys {

	public static final String DL_MIME_TYPE_DISPLAY_CONTEXT =
		"DL_MIME_TYPE_DISPLAY_CONTEXT";

	public static final String KNOWLEDGE_BASE_EXACT_MATCH =
		"KNOWLEDGE_BASE_EXACT_MATCH";

	public static final String KNOWLEDGE_BASE_KB_ARTICLE =
		"KNOWLEDGE_BASE_KB_ARTICLE";

	public static final String KNOWLEDGE_BASE_KB_ARTICLES =
		"KNOWLEDGE_BASE_KB_ARTICLES";

	public static final String KNOWLEDGE_BASE_KB_FOLDERS =
		"KNOWLEDGE_BASE_KB_FOLDERS";

	public static final String KNOWLEDGE_BASE_KB_NAVIGATION_DISPLAY_CONTEXT =
		"KNOWLEDGE_BASE_KB_NAVIGATION_DISPLAY_CONTEXT";

	public static final String
		KNOWLEDGE_BASE_KB_SUGGESTION_LIST_DISPLAY_CONTEXT =
			"KNOWLEDGE_BASE_KB_SUGGESTION_LIST_DISPLAY_CONTEXT";

	public static final String KNOWLEDGE_BASE_KB_TEMPLATE =
		"KNOWLEDGE_BASE_KB_TEMPLATE";

	public static final String KNOWLEDGE_BASE_PARENT_KB_ARTICLE =
		"KNOWLEDGE_BASE_PARENT_KB_ARTICLE";

	public static final String KNOWLEDGE_BASE_PARENT_KB_FOLDER =
		"KNOWLEDGE_BASE_PARENT_KB_FOLDER";

	public static final String KNOWLEDGE_BASE_SEARCH_KEYWORDS =
		"KNOWLEDGE_BASE_SEARCH_KEYWORDS";

	public static final String KNOWLEDGE_BASE_STATUS = "KNOWLEDGE_BASE_STATUS";

	public static final String SHOW_SIDEBAR_HEADER = "SHOW_SIDEBAR_HEADER";

	public static final String TEMP_FOLDER_NAME =
		"com.liferay.knowledge.base.admin";

}
